pub enum WarningKind {
DependencyAlsoModified,
DependentAlsoModified,
ParseFailedAfterMerge,
}Variants
DependencyAlsoModified
Entity references another entity that was also modified in this merge. The referenced entity’s contract may have changed.
DependentAlsoModified
Entity is depended on by another entity that was also modified. The dependent may have adapted to old behavior.
ParseFailedAfterMerge
The merged output failed to parse — syntactically broken merge result.