Skip to main contentModule git
Source - diff_files
- Get files changed between two refs.
- find_merge_base
- Find the merge base between two refs.
- find_repo_root
- Find the root of the git repository by walking up from the current directory.
- find_repo_root_from_path
- Find the root of the git repository that contains the given path.
Uses
git -C <dir> rev-parse --show-toplevel so it works regardless of CWD. - get_changed_files
- Get files changed in both branches relative to their merge base.
- git_show
- Show file content at a given revision.
- read_file
- Read a file from the working tree relative to a root path.